// Copyright (c) 2012 Ecma International.  All rights reserved.
// This code is governed by the BSD license found in the LICENSE file.

/*---
es5id: 15.2.3.13-1-2
description: Object.isExtensible does not throw TypeError if 'O' is null
---*/

    Object.isExtensible(null);

reportCompare(0, 0);
